blogs.EntryType (Blog Entry Type) — amici1

# `blogs.EntryType` (Blog Entry Type)

EntryType(id, name, important, remark, name_de, name_fr)

Master tables : blogs.EntryTypes (Blog Entry Types)

Slave tables : blogs.EntriesByType (Blog Entries)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Designation (name) : See `<lino.utils.mldbc.fields.BabelCharField: name>`.

- important (important) : See `<django.db.models.fields.BooleanField: important>`.

- Remark (remark) : See `<django.db.models.fields.TextField: remark>`.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Name (name_column) : See `lino_xl.lib.blogs.models.EntryType.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.blogs.models.EntryType.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.blogs.models.EntryType.overview`.

Referenced from blogs.Entry.entry_type

## Database fields

Internal name | Verbose name | Help text
id | ID |
name | Designation |
important | important |
remark | Remark |
name_de | Designation (de) |
name_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |